@@ -106,7 +106,7 @@ DlgAddCity::updateLocations( const QHash<QString, QVariant> & container )
 
 	dDebug() << "City search result:" << data;
 	QStringList vTokens = data.toString().split("|");
-	if( vTokens.at(1).compare("valid") == 0 )
+	if( vTokens.count() >= 3 && vTokens.at(1).compare("valid") == 0 )
 	{
 		if( vTokens.at(2).compare("single") == 0 ||
 		    vTokens.at(2).compare("multiple") == 0 )
@@ -172,19 +172,27 @@ DlgAddCity::updateLocations( const QHash<QString, QVariant> & container )
 			}
 		}
 	}
-	else if( vTokens.at(1).compare("timeout") == 0 )
+	else if( vTokens.count() >= 2 && vTokens.at(1).compare("timeout") == 0 )
 	{
 		KMessageBox::error(this,
 			i18n("The applet was not able to contact the server, please try again later."));
 //		dDebug() << vTokens;
 	}
-	else
+	else if( vTokens.count() >= 2 && vTokens.at(1).compare("malformed") == 0 )
+	{
+		KMessageBox::error(this,
+			i18n("Ion has rejected invalid or malformed command."));
+	} 
+	else if( vTokens.count() >= 4 )
 	{
 		KMessageBox::error(this,
 			i18n("The place '%1' is not valid. The weather-service is not able to find this place.",
 			vTokens.at(3)));
 //		dDebug() << vTokens;
 	}
+	else
+		KMessageBox::error(this, i18n("The applet was not able to contact the server, due to an unknown error."));
+	
 	dEndFunct();
 }
 
