@@ -125,6 +125,7 @@ YawpConfigDialog::YawpConfigDialog( KConfigDialog * parent, Yawp::Storage * pSto
 	btnDeleteCity->setIcon( KIcon("list-remove") );
 	btnMoveUp->setIcon( KIcon("go-up") );
 	btnMoveDown->setIcon( KIcon("go-down") );
+	btnSetTimeZone->setIcon( KIcon("clock") );
 
 	//--- THEME PAGE ---
 	//
@@ -199,7 +200,7 @@ YawpConfigDialog::YawpConfigDialog( KConfigDialog * parent, Yawp::Storage * pSto
 	//
 	connect(checkCompactPanelLayout, SIGNAL(toggled(bool)), this, SLOT(enableCompactPanelLayout(bool)));
 	connect(radioExtendedTooltip, SIGNAL(toggled(bool)), this, SLOT(enableExtendedTooltipOptions(bool)));
-
+	
 	//--- RESIZE AND SET MINIMUM SIZE ---
 	QSize minSize( parent->sizeHint() );
 	minSize.setWidth( 650 );
@@ -272,8 +273,11 @@ YawpConfigDialog::setData( const Yawp::ConfigData * data )
 	//--- UPDATE INTERVAL ---
 	iIdx = comboInterval->findData( data->iUpdateInterval );
 	comboInterval->setCurrentIndex( iIdx >= 0 ? iIdx : 0 );
-
+	
 	spinboxStartDelay->setValue( data->iStartDelay );
+	
+	groupBoxTraverseLocationsPeriodically->setChecked( data->bTraverseLocationsPeriodically );
+	spinTraverseLocationsTimeout->setValue( data->iTraverseLocationTimeout );
 
 	//--- UNIT SYSTEM ---
 	iIdx = comboTemperature->findData( data->temperatureSystem );
@@ -366,7 +370,12 @@ YawpConfigDialog::getData( Yawp::ConfigData * data )
 	//--- UPDATE INTERVAL ---
 	int iIdx = comboInterval->currentIndex();
 	data->iUpdateInterval = comboInterval->itemData( iIdx ).toInt();
+	
 	data->iStartDelay = spinboxStartDelay->value();
+	
+	data->bTraverseLocationsPeriodically = groupBoxTraverseLocationsPeriodically->isChecked();
+	data->iTraverseLocationTimeout = spinTraverseLocationsTimeout->value();
+
 
 	//--- UNIT SYSTEM ---
 	int iTempIdx  = comboTemperature->currentIndex();
