@@ -39,7 +39,7 @@
 #include <KTimeZones>
 #include <KSystemTimeZones>
 
-#if KDE_IS_VERSION(4,3,70)
+#if (KDE_VERSION_MINOR == 3 && KDE_VERSION_RELEASE >= 70) || KDE_VERSION_MINOR == 4
 	#include <KUnitConversion/Value>
 #endif
 
@@ -65,7 +65,7 @@ struct WeatherDataProcessor::Private
 
 	bool                            requestTimeZone;
 
-	QHash<Yawp::DetailsProperty, short> vDetailsPropertyMap;
+	QList<Yawp::DetailsProperty>    vDetailsProperty;
 
 	bool initIconMap(const QString & resource);
 
@@ -98,13 +98,6 @@ struct WeatherDataProcessor::Private
 	QString createPropertyText( const Yawp::DetailsProperty, const YawpDay & pDay, const YawpWeather & pWeather ) const;
 	void createPropertyStringList( const YawpDay & day, YawpWeather & weather ) const;
 	QSizeF doTextLayout( QTextLayout & textLayout, qreal dMaxWidth, qreal dOffset ) const;
-
-	inline void
-	addPropertyItem( QMap<short, Yawp::DetailsProperty> & vMap, Yawp::DetailsProperty property ) const
-	{
-		if( vDetailsPropertyMap.contains(property) )
-			vMap[ vDetailsPropertyMap.value(property) ] = property;
-	}
 };
 
 WeatherDataProcessor::WeatherDataProcessor( const Yawp::Storage * pStorage )
@@ -361,7 +354,7 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 
 	//--- remove all old days ---
 	//
-	dTracing() << "Check and remove old days";
+	dTracing() << "Check and remove old days (currently contains" << cityInfo.days().count() << "days)";
 	bool bRemovedOldDays( false );
 	currDate = cityInfo.localTime().date();
 	QDate yesterday = currDate.addDays(-1);
@@ -384,6 +377,7 @@ WeatherDataProcessor::updateLocation( CityWeather & cityInfo,
 			delete cityInfo.days().takeFirst();
 		}
 	}
+	dTracing() << "contains" << cityInfo.days().count() << "days";
 
 	//--- Add YawpWeather::SunriseSunset property and sort the properties ---
 	QList<YawpDay *>::iterator itDay = cityInfo.days().begin();
@@ -501,6 +495,9 @@ WeatherDataProcessor::loadData( CityWeather & cityInfo ) const
 			updateLocation( cityInfo, data );
 			bReturn = true;
 		}
+		else
+			dTracing() << "cached values are out of date for" << cityInfo.city() << cityInfo.country()
+				<< "  provider:" << cityInfo.provider();
 		file.close();
 	}
 	return bReturn;
@@ -509,13 +506,8 @@ WeatherDataProcessor::loadData( CityWeather & cityInfo ) const
 void
 WeatherDataProcessor::createDetailsPropertyMap( const QList<Yawp::DetailsProperty> & vProperties )
 {
-	d->vDetailsPropertyMap.clear();
-	QList<Yawp::DetailsProperty>::const_iterator itList = vProperties.begin();
-	short iPos(0);
-	for( ; itList != vProperties.end(); ++itList, ++iPos )
-	{
-		d->vDetailsPropertyMap[ *itList ] = iPos;
-	}
+	d->vDetailsProperty.clear();
+	d->vDetailsProperty = vProperties;
 }
 
 bool
@@ -643,7 +635,7 @@ WeatherDataProcessor::Private::convertDistance( const QString & value,
 
 	if( fromSystem != distanceSystem )
 	{
-#if (KDE_VERSION_MINOR == 3 && KDE_VERSION_RELEASE >= 70) || KDE_VERSION_MINOR == 4
+#if KDE_IS_VERSION(4,3,70)
 		KUnitConversion::Value v( (double) fValue, fromSystem);
 		fValue = v.convertTo(distanceSystem).number();
 #elif KDE_VERSION_MINOR == 3
@@ -664,7 +656,7 @@ WeatherDataProcessor::Private::convertPressure( const QString & value,
 		return SHRT_MAX;
 	if( fromSystem != pressureSystem )
 	{
-#if (KDE_VERSION_MINOR == 3 && KDE_VERSION_RELEASE >= 70) || KDE_VERSION_MINOR == 4
+#if KDE_IS_VERSION(4,3,70)
 		KUnitConversion::Value v( (double) fValue, fromSystem);
 		fValue = v.convertTo(pressureSystem).number();
 #elif KDE_VERSION_MINOR >= 3
@@ -687,7 +679,7 @@ WeatherDataProcessor::Private::convertTemp( const QString & value,
 
 	if( fromSystem != temperatureSystem )
 	{
-#if (KDE_VERSION_MINOR == 3 && KDE_VERSION_RELEASE >= 70) || KDE_VERSION_MINOR == 4
+#if KDE_IS_VERSION(4,3,70)
 		KUnitConversion::Value v( (double) fValue, fromSystem);
 		fValue = v.convertTo(temperatureSystem).number();
 #elif KDE_VERSION_MINOR >= 3
@@ -709,7 +701,7 @@ WeatherDataProcessor::Private::convertSpeed( const QString & value,
 
 	if( fromSystem != speedSystem )
 	{
-#if (KDE_VERSION_MINOR == 3 && KDE_VERSION_RELEASE >= 70) || KDE_VERSION_MINOR == 4
+#if KDE_IS_VERSION(4,3,70)
 		KUnitConversion::Value v( (double) fValue, fromSystem);
 		fValue = v.convertTo(speedSystem).number();
 #elif KDE_VERSION_MINOR >= 3
@@ -775,7 +767,6 @@ WeatherDataProcessor::Private::findDateForWeekday( QDate & currDate, const QStri
 {
 	QString sLookingDayNameUtf8 = sLookingDayName.toUtf8();
 	QString vWeekdayUtf8;
-	KDateTime kDate(currDate);
 
 	for(int iOffset = 0; iOffset < 6; ++iOffset )
 	{
@@ -797,16 +788,7 @@ WeatherDataProcessor::Private::findDateForWeekday( QDate & currDate, const QStri
 		if( vWeekdayUtf8.startsWith( sLookingDayNameUtf8, Qt::CaseInsensitive ) )
 			return true;
 
-		dTracing() << "  4) compare" << sLookingDayNameUtf8 << " with " << kDate.toString("%a").toUtf8();
-		if( sLookingDayNameUtf8.startsWith( kDate.toString("%a"), Qt::CaseInsensitive ) )
-			return true;
-		
-		dTracing() << "  5) compare" << sLookingDayNameUtf8 << " with " << i18n(kDate.toString("%a").toUtf8().constData());
-		if( sLookingDayNameUtf8.startsWith( i18n(kDate.toString("%a").toUtf8().constData()), Qt::CaseInsensitive ) )
-			return true;
-		
 		currDate = currDate.addDays(-1);
-		kDate = kDate.addDays(-1);
 	}
 	return false;
 }
@@ -859,85 +841,64 @@ WeatherDataProcessor::Private::initIconMap(const QString & resource)
 void
 WeatherDataProcessor::Private::createPropertyStringList( const YawpDay & day, YawpWeather & weather ) const
 {
-	QMap<short, Yawp::DetailsProperty> vPropertyMap;
-
-	//--- check for properties and add them to the list ---
-	if( !weather.description().isEmpty() )
-		addPropertyItem( vPropertyMap, Yawp::WeatherDescription );
-	if( weather.temperatureRealFeelHigh() < SHRT_MAX && weather.temperatureRealFeelLow() < SHRT_MAX )
-		addPropertyItem( vPropertyMap, Yawp::RealfeelTemperature );
-	if( weather.dewpoint() < SHRT_MAX )
-		addPropertyItem( vPropertyMap, Yawp::Dewpoint );
-	if( weather.pressure() < SHRT_MAX )
-		addPropertyItem( vPropertyMap, Yawp::Pressure );
-	if( weather.uvIndex() < SHRT_MAX )
-		addPropertyItem( vPropertyMap, Yawp::UV );
-	if( weather.visibility() < SHRT_MAX )
-		addPropertyItem( vPropertyMap, Yawp::Visibility );
-	if( day.sunrise().isValid() && day.sunset().isValid() )
-		addPropertyItem( vPropertyMap, Yawp::SunriseSunset );
-
 	QFont font( KGlobalSettings::generalFont() );
 	font.setBold(false);
 	font.setPixelSize(15);
 	QTextLayout textLayout;
 	textLayout.setFont(font);
-
-	QMap<short, Yawp::DetailsProperty>::const_iterator itMap = vPropertyMap.begin();
-	QString sText;
-	QString sOffsetText(2, QChar(' '));
+	
+	QString sOffsetText(3, QChar(' '));
 	QFontMetrics fm(font);
 	qreal dOffsetWidth( (qreal)fm.width(sOffsetText) );
 
-	for( ; itMap != vPropertyMap.end(); ++itMap )
+	//  go though all property items that has been specified to show in details area
+	//
+	QList<Yawp::DetailsProperty>::const_iterator itMap = vDetailsProperty.begin();
+	for( ; itMap != vDetailsProperty.end(); itMap++ )
 	{
-		sText = createPropertyText(*itMap, day, weather);
-
-/**** Just for debug to test the linebreak stuff. When a text needs to be wrapped around several lines.
-      than we will indent all lines expect the first one. This way it is easy to see when a new property text
-      starts.
-		switch( qrand() % 5 )
-		{
-			case 0: break;
-			case 1: case 4:	sText.append(" A little bit more text to test the line-break."); break;
-			case 2: sText.append(" xyz abc"); break;
-			case 3: sText.append(" A short text at the end."); break;
-		}
-*/
+		//--- Create property text for requested property ---
+		QString sText = createPropertyText(*itMap, day, weather);
+		
+		//--- When propery text is empty, continue with next property ---
+		if( sText.isEmpty() )
+			continue;
+	
+		/*   When a text needs to be wrapped around several lines.
+		 *   than we will indent all lines expect the first one.
+		 *   This way it is easy to see when a new property text starts.
+		 */
 		sText.replace('\n', QChar::LineSeparator);
 		textLayout.setText( sText );
 		QSizeF textSize = doTextLayout( textLayout, MAX_PROPERTY_TEXT_WIDTH, dOffsetWidth);
-		if( textSize.width() > MAX_PROPERTY_TEXT_WIDTH )
-		{
-			qreal dTextLength(0.0f);
-			for( int i=0; i<textLayout.lineCount(); ++i )
-				dTextLength += (i+1 == textLayout.lineCount() ? MAX_PROPERTY_TEXT_WIDTH : textLayout.lineAt(i).naturalTextWidth());
-			QFontMetrics fm(font);
-			sText = fm.elidedText(sText, Qt::ElideRight, dTextLength);
-			textLayout.setText( sText );
-			textSize = doTextLayout( textLayout, MAX_PROPERTY_TEXT_WIDTH, dOffsetWidth );
-		}
 
-		for( int i=0; i<textLayout.lineCount(); ++i )
+		/*   Add the propery text lines for current property to property-text-line-list
+		 */
+		for( int iLine = 0; iLine < textLayout.lineCount(); iLine++ )
 		{
-			QTextLine line( textLayout.lineAt(i) );
-			int iTS = line.textStart();
-			int iTW = line.textLength();
+			qreal dMaxLineWidth = (iLine == 0 ? MAX_PROPERTY_TEXT_WIDTH : MAX_PROPERTY_TEXT_WIDTH-dOffsetWidth);
 
-			QChar::Category category( textLayout.text().at(iTS+iTW-1).category() );
-			iTW += (category == QChar::Separator_Line || category == QChar::Separator_Space ? -1 : 0);
-//			dDebug() << line.textStart() << line.textLength() << textLayout.text().mid( iTS, iTW ) << "   " << line.naturalTextWidth();
-			if( i==0 )
-				weather.propertyTextLines().append( textLayout.text().mid( iTS, iTW ) );
+			QTextLine line = textLayout.lineAt(iLine);
+			int iStart = line.textStart();
+			int iWidth = line.textLength();
+
+			QChar::Category category( textLayout.text().at(iStart+iWidth-1).category() );
+			iWidth += (category == QChar::Separator_Line || category == QChar::Separator_Space ? -1 : 0);
+
+			// When text line does not fit we have to trim textline
+			// methode doTextLayout will abort text layout when one line does not fit
+			QString sText = textLayout.text().mid( iStart, iWidth );
+			if( line.naturalTextWidth() > dMaxLineWidth )
+				sText =  fm.elidedText(sText, Qt::ElideRight, dMaxLineWidth);
+			
+			//--- Finally, append the text line to the property text lines ---
+			if( iLine == 0 )
+				weather.propertyTextLines().append( sText );
 			else
-				weather.propertyTextLines().append( sOffsetText + textLayout.text().mid( iTS, iTW ) );
+				weather.propertyTextLines().append( sOffsetText + sText );
 		}
-
-//		dDebug() << "--------------------------------------------";
 	}
 }
 
-
 inline QString
 WeatherDataProcessor::mapConditionIcon( const QString & iconName ) const
 {
@@ -949,68 +910,131 @@ WeatherDataProcessor::Private::createPropertyText( const Yawp::DetailsProperty p
                                                    const YawpDay & day,
                                                    const YawpWeather & weather ) const
 {
+	QString sText;
+  
 	switch( property )
 	{
 	case Yawp::Dewpoint:
-		return i18n("Dewpoint: %1", weather.dewpoint())	+ QChar(0xB0);
+		if( weather.dewpoint() < SHRT_MAX )
+			return i18n("Dewpoint: %1", weather.dewpoint())	+ QChar(0xB0);
 		break;
 
 	case Yawp::Pressure:
+		if( weather.pressure() < SHRT_MAX )
 		{
-			QString sTmp( i18n("Pressure: %1 %2",
+			sText = i18n("Pressure: %1 %2",
 				weather.pressure(),
-				Utils::GetUnitString(pressureSystem)) );
+				Utils::GetUnitString(pressureSystem));
 
 			if( weather.pressureTendency() != "Unavailable" &&
 			    !weather.pressureTendency().isEmpty() )
 			{
-				sTmp.append( QString("  %1")
+				sText.append( QString("  %1")
 					.arg( i18nc("Pressure", weather.pressureTendency().toUtf8().constData())) );
 			}
-			return sTmp;
 		}
 		break;
 
-		case Yawp::RealfeelTemperature:
+	case Yawp::RealfeelTemperature:
 		{
+			int iTempCount = 0;
+			
 			QString sHigh(i18n("N/A"));
 			QString sLow(i18n("N/A"));
+			
 			if( weather.temperatureRealFeelHigh() < SHRT_MAX )
+			{
 				sHigh = QString::number(weather.temperatureRealFeelHigh()) + QChar(0xB0);
+				iTempCount += 1;
+			}
 			if( weather.temperatureRealFeelLow() < SHRT_MAX )
+			{
 				sLow = QString::number(weather.temperatureRealFeelLow()) + QChar(0xB0);
-			return i18n("Real feel: %1 / %2", sHigh, sLow );
+				iTempCount += 1;
+			}
+			
+			//--- Return the string only when we have at least one valid temperature ---
+			if( iTempCount > 0 )
+				return i18n("Real feel: %1 / %2", sHigh, sLow );
 		}
 		break;
 
-		case Yawp::SunriseSunset:
+	case Yawp::SunriseSunset:
 		{
+			int iTempCount = 0;
+			
 			QString sSunrise(i18n("N/A"));
 			QString sSunset(i18n("N/A"));
+			
 			if( day.sunrise().isValid() )
+			{
 				sSunrise = KGlobal::locale()->formatTime(day.sunrise());
+				iTempCount += 1;
+			}
 			if( day.sunset().isValid() )
+			{
 				sSunset = KGlobal::locale()->formatTime(day.sunset());
-			return i18n("Sunrise at %1, sunset at %2", sSunrise, sSunset);
+				iTempCount += 1;
+			}
+			if( iTempCount > 0 )
+				return i18n("Sunrise at %1, sunset at %2", sSunrise, sSunset);
 		}
 		break;
 
-		case Yawp::UV:
+	case Yawp::UV:
+		if( weather.uvIndex() < SHRT_MAX )
+		{
 			return i18n("UV Index: %1  %2",
 				weather.uvIndex(), weather.uvRating());
-			break;
+		}
+		break;
 
-		case Yawp::Visibility:
+	case Yawp::Visibility:
+		if( weather.visibility() < SHRT_MAX )
+		{
 			return i18n("Visibility: %1 %2",
 				weather.visibility(),
 				Utils::GetUnitString( distanceSystem ));
-				break;
+		}
+		break;
 
-		case Yawp::WeatherDescription:
-			return Utils::LocalizedWeatherString(weather.description());
-			break;
+	case Yawp::WeatherDescription:
+		if( !weather.description().isEmpty() )
+		{
+			// weather condition from Wunderground contains >&deg;<
+			// for the degree-character,
+			// Utils::LocalizedWeatherString will replace 'C - Celsius' and 
+			// 'F - Fahrenheit' to lower capitals
+			// so we replace both of them after string has been translated
+			// through Utils::LocalizedWeatherString as NASTY WORKAROUND
+			sText = Utils::LocalizedWeatherString(weather.description());
+			int iPos = 0;
+
+			while( iPos >= 0 )
+			{
+				iPos = sText.indexOf("&deg;", iPos);
+				if( iPos > 0 )
+				{
+					sText.replace(iPos, 5, QChar(0xB0));
+
+					// Utils::LocalizedWeatherString is adding a space-character
+					// between degree-character and the temperature unit sign (C/F)
+					// this is the reason, why we replace two characters
+					if( sText.mid(iPos+1, 1).compare(" ") == 0 )
+						sText.remove(iPos+1, 1);
+					
+					QString sTemp = sText.mid(iPos+1, 1);
+					if( sTemp.compare("f", Qt::CaseSensitive) == 0)
+						sText.replace(iPos+1, 1, 'F');
+					else if( sTemp.compare("c", Qt::CaseSensitive) == 0 )
+						sText.replace(iPos+1, 1, 'C');
+				}
+				iPos = (iPos+1 < sText.length() && iPos >= 0 ? iPos+1 : -1);
+			}
+		}
+		break;
 	}
-	return QString();
+	return sText;
 }
 
 QSizeF
