@@ -86,7 +86,11 @@ YaWP::YaWP( QObject * parent, const QVariantList & args )
 	  m_iIdPendingEngineConnection(-1)
 {
 	Q_INIT_RESOURCE(yawpresource);
-	dStartFunct() << "============================================\n\n";
+	dStartFunct() << "============================================";
+	dInfo();
+	dInfo() << "yaWP" << YAWP_VERSION_STRING << "compiled at" << __DATE__ << __TIME__ << "for KDE" << KDE_VERSION_STRING;
+	dInfo() << "yaWP" << YAWP_VERSION_STRING << "is running on KDE" << KDE::versionString();
+	dInfo();
 
 	Plasma::DataEngine * pEngine = dataEngine("weather");
 	m_storage.setEngine( pEngine );
@@ -94,6 +98,15 @@ YaWP::YaWP( QObject * parent, const QVariantList & args )
 	WeatherDataProcessor * pDataProcessor = new WeatherDataProcessor( &m_storage );
 	m_pWeatherModel = new WeatherServiceModel( &m_storage, this, pDataProcessor );
 	m_pWeatherModel->setObjectName("EngineModel");
+	
+//	CityWeather dummyCity;
+//	dummyCity.setProvider(QString("wunderground"));
+//	dummyCity.setCity("Garoua, Cameroon");
+//	dummyCity.setCountry("Cameroon");
+//	dummyCity.setCountryCode("cm");
+//	dummyCity.setExtraData("airport:FKKR");
+//	dummyCity.setTimeZone("Africa/Douala");
+//	m_pWeatherModel->addCity(dummyCity);
 
 	m_stateMachine.setServiceModel( m_pWeatherModel );
 
@@ -144,8 +157,9 @@ YaWP::YaWP( QObject * parent, const QVariantList & args )
 		#else
 				m_configData.speedSystem	= WeatherUtils::MilesAnHour;
 		#endif
-#endif
-}
+	#endif
+	}
+	
 	m_configData.todaysWeatherPanelFormat	= Yawp::PanelTemperature | Yawp::PanelIcon;
 	m_configData.forecastWeatherPanelFormat	= Yawp::PanelTemperature | Yawp::PanelIcon;
 	m_configData.iPanelForecastDays		= 3;
@@ -162,6 +176,10 @@ YaWP::YaWP( QObject * parent, const QVariantList & args )
 	m_configData.bUseCompactPanelLayout		= false;
 	m_configData.bUseExtendedTooltip	= true;
 	m_configData.extendedTooltipOptions	= Yawp::PreviewPage | Yawp::SatellitePage;
+	
+	m_configData.bTraverseLocationsPeriodically = false;
+	m_configData.iTraverseLocationTimeout = 30;
+
 
 	m_configData.vDetailsPropertyRankingList
 		<< Yawp::WeatherDescription
@@ -179,7 +197,8 @@ YaWP::YaWP( QObject * parent, const QVariantList & args )
 	m_pManualUpdate = new QAction ( i18n ("&Refresh"), this );
 	m_pManualUpdate->setIcon ( KIcon ( "view-refresh" ) );
 	addAction( "refresh", m_pManualUpdate );
-	connect ( m_pManualUpdate, SIGNAL(triggered()), m_pWeatherModel, SLOT(reconnectEngine()) );
+	connect ( m_pManualUpdate, SIGNAL(triggered()),
+		  m_pWeatherModel, SLOT(reconnectEngine()) );
 
 	QAction * aboutAction = new QAction(i18n("&About"), this);
 	aboutAction->setIcon( KIcon("help-about") );
@@ -198,6 +217,7 @@ YaWP::YaWP( QObject * parent, const QVariantList & args )
 	QAction * separator2 = new QAction ( this );
 	separator2->setSeparator ( true );
 
+
 	m_actions.append( m_pManualUpdate );
 	m_actions.append( aboutAction );
 	m_actions.append( separator1 );
@@ -338,6 +358,9 @@ YaWP::init()
 		m_iIdPendingEngineConnection = startTimer( m_configData.iStartDelay*60*1000 );
 	else
 		QTimer::singleShot( 20, this, SLOT(slotConfigurationRequired()) );
+	
+	startTraverseLocationTimeout();
+	
 	dEndFunct();
 }
 
@@ -358,6 +381,10 @@ YaWP::loadConfig()
 		= cfg.readEntry( "update interval", QVariant(m_configData.iUpdateInterval) ).toInt();
 	m_configData.iStartDelay
 		= cfg.readEntry( "start delay", QVariant(m_configData.iStartDelay) ).toInt();
+	m_configData.bTraverseLocationsPeriodically
+		= cfg.readEntry( "traverse locations", m_configData.bTraverseLocationsPeriodically );
+	m_configData.iTraverseLocationTimeout
+		= cfg.readEntry( "traverse locations timeout", QVariant(m_configData.iTraverseLocationTimeout) ).toInt();
 
 	m_configData.distanceSystem
 		= (YAWP_DISTANCE_UNIT)cfg.readEntry( "system.distance",
@@ -492,7 +519,9 @@ YaWP::saveConfig()
 	/*** SETTINGS PAGE ***/
 	cfg.writeEntry( "update interval",			(int)m_configData.iUpdateInterval );
 	cfg.writeEntry( "start delay",				(int)m_configData.iStartDelay );
-
+	cfg.writeEntry( "traverse locations",		m_configData.bTraverseLocationsPeriodically );
+	cfg.writeEntry( "traverse locations timeout",	m_configData.iTraverseLocationTimeout );
+	
 	cfg.writeEntry( "system.distance",          (int)m_configData.distanceSystem );
 	cfg.writeEntry( "system.pressure",          (int)m_configData.pressureSystem );
 	cfg.writeEntry( "system.temperature",		(int)m_configData.temperatureSystem );
@@ -736,6 +765,8 @@ YaWP::configAccepted()
 	m_pWeatherModel->disconnectEngine();
 	stopPendingEngineConnection();
 
+	stopTraverseLocationTimeout();
+
 	dDebug() << "configuration changed..."
 	         << "    model changed" << m_pConfigDlg->cityModelChanged();
 	if( m_pConfigDlg->cityModelChanged() )
@@ -771,7 +802,9 @@ YaWP::configAccepted()
 	//--- trigger the update-process ---
 	if( bHasCities )
 		m_iIdPendingEngineConnection = startTimer( m_pConfigDlg->citySettingsChanged() ? 0 : 3 * 60 * 1000 );
-		
+	
+	startTraverseLocationTimeout();
+	
 	// to make sure we will change the theme
 	constraintsEvent( Plasma::FormFactorConstraint | Plasma::SizeConstraint );
 	update();
@@ -789,6 +822,10 @@ YaWP::mousePressEvent( QGraphicsSceneMouseEvent * event )
 		dEndFunct();
 		return;
 	}
+	
+	// every time user interacts with this plasmoid, we reset the timer
+	// to automatically switch to next location
+	stopTraverseLocationTimeout();
 
 	m_pCurrLayout->setContentsRect( contentsRect() );
 	const Yawp::PageType currPage( m_stateMachine.currentPage() );
@@ -989,6 +1026,11 @@ YaWP::mousePressEvent( QGraphicsSceneMouseEvent * event )
 		dEndFunct();
 		return;
 	}
+	
+	//   When user did no click on an animation area, than we have to restart timeout
+	//   to traverse through all locations periodically
+	startTraverseLocationTimeout();
+	
 	dEndFunct();
 }
 
@@ -1000,6 +1042,13 @@ YaWP::timerEvent ( QTimerEvent * event )
 		stopPendingEngineConnection();
 		m_pWeatherModel->reconnectEngine();
 	}
+	else if( event->timerId() == m_timerTraverseLocations.timerId() )
+	{
+		stopTraverseLocationTimeout();
+		
+		int iSelectedCityIndex = (m_configData.iCityIndex + 1) % m_pWeatherModel->rowCount();
+		initPageChange( CITY_CHANGED, iSelectedCityIndex, iSelectedCityIndex > m_configData.iCityIndex );
+	}
 	Plasma::Applet::timerEvent(event);
 }
 
@@ -1421,6 +1470,11 @@ YaWP::paintTopWeatherInfos( QPainter * painter, int iDayIndex, bool bShowFancyTe
 	QRectF		rect;
 	QFontMetrics	fontMetrics(font);
 	const YawpWeather * pWeather = m_stateMachine.weather( iDayIndex );
+	
+	const CityWeather * pCity = m_stateMachine.currentCity();
+	if( pCity )
+		dTracing() << pCity->city() << pCity->country() << " provider:" << pCity->provider()
+			<< " contains" << pCity->days().count() << "days";
 
 	if( pWeather )
 	{
@@ -1549,6 +1603,8 @@ YaWP::animationFinished()
 	m_pageAnimator.vPages[0] = m_pageAnimator.vPages[1] = QPixmap();
 	m_tAnimationType = NoAnimation;
 	m_iAnimationIndex = -1;
+	
+	startTraverseLocationTimeout();
 	dEndFunct();
 }
 
@@ -1881,10 +1937,9 @@ YaWP::paintWeatherDetails( QPainter * painter )
 		
 		if( pCity->observationPeriode().isValid() )
 		{
-			QDateTime obsTime( pCity->observationPeriode() );
-			if( pCity->timeZone().isValid() )
-				obsTime = pCity->timeZone().convert(KSystemTimeZones::local(), obsTime);
-			
+			QDateTime obsTime;
+			obsTime = pCity->fromLocalTime(pCity->observationPeriode());
+
 			sUpdateString.append( QString("\n%1 %2")
 				.arg(i18n("Observation Periode:"))
 				.arg(KGlobal::locale()->formatDateTime(obsTime, KLocale::FancyShortDate, false)) );
@@ -2430,5 +2485,19 @@ YaWP::stopPendingEngineConnection()
 	}
 }
 
+void
+YaWP::startTraverseLocationTimeout()
+{
+	if( m_configData.bTraverseLocationsPeriodically && m_pWeatherModel->rowCount() > 1 )
+		m_timerTraverseLocations.start( m_configData.iTraverseLocationTimeout * 1000, this );
+}
+
+void
+YaWP::stopTraverseLocationTimeout()
+{
+	if( m_timerTraverseLocations.isActive() )
+		m_timerTraverseLocations.stop();
+}
+
 // This is the command that links your applet to the .desktop file
 K_EXPORT_PLASMA_APPLET(yawp, YaWP);
