@@ -32,7 +32,6 @@
 
 //--- KDE4 ---
 #include <KTimeZone>
-#include <Plasma/Weather/WeatherUtils>
 
 //--- std ---
 #include <limits.h>
@@ -227,8 +226,20 @@ public:
 	const QString & creditURL() const { return m_sCreditURL; }
 	void setCreditURL(const QString & sCreditURL) { m_sCreditURL = sCreditURL; }
 	
-	
+	/*** Returns the current local time depending on specifed timezone. */
 	QDateTime localTime() const;
+	
+	/*** Converts dateTime from local timezone (specified by CityInfo::timeZone()) to system-timezone. */
+	QDateTime fromLocalTime(const QDateTime & dateTime) const;
+	
+	/*** Converts dateTime from system-timezone to local timezone (specified by CityInfo::timeZone()) */
+	QDateTime toLocalTime(const QDateTime & dateTime) const;
+	
+	/*** Check if last observation time was during daytime or nightime.
+	 *  We use oberservation time instead of current time, to show the weather with the "Current Weather Information"
+	 *  until we update this information. This way it might happens, that we see the icon for daytime event if it
+	 *  is already nightime and vice versa.
+	 */
 	bool isDayTime( const YawpDay * day ) const;
 
 private:
