@@ -93,12 +93,15 @@ enum DetailsProperty{
 */
 struct ConfigData
 {
+	int                        iCityIndex;
+
+	//--- update behaviour options ---
 	int                        iUpdateInterval;		// in minutes
 	int                        iStartDelay;			// in minutes
+	bool                       bTraverseLocationsPeriodically;
+	int                        iTraverseLocationTimeout;
 
-	int                        iCityIndex;
-	int                        iAnimationDuration;
-
+	//--- theme options ---
 	bool                       bUseCustomTheme;
 	bool                       bUseCustomThemeBackground;
 	bool                       bUseCustomFontColor;
@@ -123,6 +126,8 @@ struct ConfigData
 	bool                       bUseCompactPanelLayout;
 
 	//--- desktop animation options ---
+	int                        iAnimationDuration;
+
 	PageAnimator::Transition   daynamesAnimation;
 	PageAnimator::Transition   detailsAnimation;
 	PageAnimator::Transition   pageAnimation;
