@@ -1,3 +1,22 @@
+/***************************************************************************
+ *   Copyright (C) 2007-2008 by Shawn Starr <shawn.starr@rogers.com>       *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
+ ***************************************************************************/
+
 /*************************************************************************\
 *   Copyright (C) 2009 by Ulf Kreissig                                    *
 *   udev@gmx.net                                                          *
@@ -19,6 +38,7 @@
 \*************************************************************************/
 
 //--- LOCAL ---
+#include "../config.h"
 #include "ion_accuweather.h"
 #include "logger/streamlogger.h"
 
@@ -31,6 +51,7 @@
 //--- KDE4 ---
 #include <Plasma/DataContainer>
 #include <KDateTime>
+#include <kdeversion.h>
 
 #define TAG_TEMP		1
 #define	TAG_SPEED		2
@@ -56,6 +77,10 @@ struct AccuWeatherIon::Private
 	//--- Image jobs ---
 	QHash<QByteArray, ImageData *>    vImageData;	// Satellite url is the key to the ImageData
 	QHash<KJob *,  ImageData *>       vImageJobs;
+	
+#if KDE_IS_VERSION(4,4,80)
+	QStringList                       sourcesToReset;
+#endif
 };
 
 AccuWeatherIon::AccuWeatherIon( QObject * parent, const QVariantList & args )
@@ -63,6 +88,13 @@ AccuWeatherIon::AccuWeatherIon( QObject * parent, const QVariantList & args )
 	  d( new Private )
 {
 	Q_UNUSED(args)
+	
+	dInfo() << "AccuWeatherIon" << YAWP_VERSION_STRING << "compiled at" << __DATE__ << __TIME__ << "for KDE" << KDE_VERSION_STRING;
+
+
+#if defined(MIN_POLL_INTERVAL)
+	setMinimumPollingInterval(MIN_POLL_INTERVAL);
+#endif 
 
 	//--- DAY ICONS ---
 	d->vConditionList["01"] = ClearDay;
@@ -111,7 +143,7 @@ AccuWeatherIon::AccuWeatherIon( QObject * parent, const QVariantList & args )
 
 AccuWeatherIon::~AccuWeatherIon()
 {
-	reset();
+	cleanup();
 	delete d;
 }
 
@@ -132,14 +164,7 @@ AccuWeatherIon::updateIonSource( const QString & source )
 	
 	QStringList vTokens = source.split('|');
 
-	if( vTokens.size() < 3 )
-	{
-        setData(source, "validate", QString("%1|timeout").arg(IonName));
-		dEndFunct();
-        return true;
-    }
-
-	if( vTokens.at(1) == ActionValidate )	// Look for places to match
+	if( vTokens.count() >= 3 && vTokens.at(1) == ActionValidate )	// Look for places to match
 	{
 		QString sPlace( vTokens.at(2).simplified() );
 		if( !d->vActiveJobs.contains( QString("%1|%2").arg(sPlace).arg(ActionValidate) ) )
@@ -147,7 +172,7 @@ AccuWeatherIon::updateIonSource( const QString & source )
 		dEndFunct();
 		return true;
 	}
-	else if( vTokens.at(1) == ActionWeather )	// Weather data request for a specific locaion
+	else if( vTokens.count() >= 3 && vTokens.at(1) == ActionWeather )	// Weather data request for a specific locaion
 	{
 		if( vTokens.size() >= 4 )
 		{
@@ -187,6 +212,14 @@ AccuWeatherIon::updateIonSource( const QString & source )
 		dEndFunct();
 		return true;
 	}
+	else
+	{
+#if KDE_IS_VERSION(4,4,80)
+		setData(source, "validate", QString("%1|malformed").arg(IonName)); 
+#else
+		setData(source, "validate", QString("%1|timeout").arg(IonName));
+#endif
+	}
 	dEndFunct();
 	return false;
 }
@@ -195,6 +228,29 @@ void
 AccuWeatherIon::reset()
 {
 	dStartFunct();
+
+	cleanup();
+	
+	/**  Triggered when we get initial setup data for ions that provide a list of places
+	*/
+#if KDE_IS_VERSION(4,5,2) || KDE_IS_VERSION(4,5,60)
+	d->sourcesToReset = sources();
+	updateAllSources();
+#elif KDE_IS_VERSION(4,4,80)
+	d->sourcesToReset = sources();
+	updateAllSources();
+	emit(resetCompleted(this, true));
+#elif KDE_IS_VERSION(4,2,85) || KDE_IS_VERSION(4,3,80)
+	emit(resetCompleted(this, true));
+#endif
+	dEndFunct();
+}
+
+void
+AccuWeatherIon::cleanup()
+{
+	dStartFunct();
+	
 	QHash<KJob *, XmlJobData *>::iterator it;
 	for( it = d->vSearchJobs.begin(); it != d->vSearchJobs.end(); ++it )
 	{
@@ -229,17 +285,13 @@ AccuWeatherIon::reset()
 	/* contains the same values than vImageJobs, but the key differs so that we will find it by url. */
 	d->vImageData.clear();
 	d->vImageJobs.clear();
-	
 	d->vActiveJobs.clear();
-
-#if KDE_VERSION_MINOR >= 3
-	/**  Triggered when we get initial setup data for ions that provide a list of places */
-    emit(resetCompleted(this, true));
-#endif
+	
 	dEndFunct();
 }
 
 
+
 /*********************************************************************************\
 *                         S E A R C H   L O C A T I O N S                         *
 \*********************************************************************************/
@@ -690,7 +742,10 @@ AccuWeatherIon::readCurrentConditions( QXmlStreamReader & xml, WeatherData & wea
 			else if( xml.name().compare("pressure") == 0 )
 			{
 				weather.pressureTendency = xml.attributes().value("state").toString();
-				weather.pressure = xml.readElementText();
+				if( weather.pressureTendency.compare("Unavailable", Qt::CaseInsensitive) == 0 )
+					weather.pressureTendency.clear();
+				else
+					weather.pressure = xml.readElementText();
 			}
 			else if( xml.name().compare("visibility") == 0 )
 				weather.visibility = xml.readElementText();
