@@ -38,6 +38,7 @@
 \*************************************************************************/
 
 //--- LOCAL ---
+#include "../config.h"
 #include "ion_wunderground.h"
 #include "logger/streamlogger.h"
 
@@ -129,6 +130,7 @@ struct XmlWeatherData
 	 *  We will return the results to the widget, when all jobs have been completed.
 	 */
 	short iActiveJobs;
+	short iSuccededJobs;
 };
 
 
@@ -141,7 +143,7 @@ struct WundergroundIon::Private
 	QHash<QString, XmlLookupResult *> vLookupResults;	// key is the location we're looking for
 	QHash<QString, XmlWeatherData *>  vWeatherData;	// key is ServiceId (e.g.: airport:EDDC)
 	
-#if KDE_IS_VERSION(4,5,2)
+#if KDE_IS_VERSION(4,4,80)
 	QStringList                       sourcesToReset;
 #endif
 	
@@ -168,6 +170,14 @@ WundergroundIon::WundergroundIon( QObject * parent, const QVariantList & args )
 	: IonInterface(parent, args),
 	  d( new Private )
 {
+	Q_UNUSED(args);
+	
+	dInfo() << "WundergroundIon" << YAWP_VERSION_STRING << "compiled at" << __DATE__ << __TIME__ << "for KDE" << KDE_VERSION_STRING;
+	
+#if defined(MIN_POLL_INTERVAL)
+	setMinimumPollingInterval(MIN_POLL_INTERVAL);
+#endif 
+
 	d->vIconConditionMap["chancerain"] = ChanceShowersDay;
 	d->vIconConditionMap["chancesnow"] = ChanceSnowDay;
 	d->vIconConditionMap["chancetstorms"] = ChanceThunderstormDay;
@@ -196,7 +206,7 @@ WundergroundIon::WundergroundIon( QObject * parent, const QVariantList & args )
 
 WundergroundIon::~WundergroundIon()
 {
-	reset();
+	cleanup();
 	delete d;
 }
 
@@ -210,6 +220,28 @@ void
 WundergroundIon::reset()
 {
 	dStartFunct();
+	
+	cleanup();
+
+	/**  Triggered when we get initial setup data for ions that provide a list of places */
+#if KDE_IS_VERSION(4,5,2) || KDE_IS_VERSION(4,5,60)
+	d->sourcesToReset = sources();
+	updateAllSources();
+#elif KDE_IS_VERSION(4,4,80)
+	d->sourcesToReset = sources();
+	updateAllSources();
+	emit(resetCompleted(this, true));
+#elif KDE_IS_VERSION(4,2,85) || KDE_IS_VERSION(4,3,80)
+	emit(resetCompleted(this, true));
+#endif
+	dEndFunct();
+}
+
+void
+WundergroundIon::cleanup()
+{
+	dStartFunct();
+	
 	dDebug() << "Delete Jobs";
 	QHash<KJob *, XmlServiceData *>::iterator itService;
 	for( itService = d->vServiceJobs.begin(); itService != d->vServiceJobs.end(); ++itService )
@@ -236,14 +268,7 @@ WundergroundIon::reset()
 		delete pWeather;
 	}
 	d->vWeatherData.clear();
-
-	/**  Triggered when we get initial setup data for ions that provide a list of places */
-#if KDE_IS_VERSION(4,5,2)
-	d->sourcesToReset = sources();
-	updateAllSources();
-#elif KDE_VERSION_MINOR >= 3
-	emit(resetCompleted(this, true));
-#endif
+	
 	dEndFunct();
 }
 
@@ -253,13 +278,8 @@ WundergroundIon::updateIonSource( const QString & sSource )
 	dStartFunct() << sSource;
 	
 	QStringList vTokens = sSource.split('|');
-	if( vTokens.size() < 3 )
-	{
-        setData(sSource, "validate", QString("%1|timeout").arg(IonName));
-		dEndFunct();
-		return true;
-    }
-	else if( vTokens.at(1) == ActionValidate )
+	
+	if( vTokens.size() >= 3 && vTokens.at(1) == ActionValidate )
 	{
 		QString sLocation( vTokens.at(2).simplified() );
 		if( d->vLookupResults.contains(sLocation) )	// we are already looking for this location, right now
@@ -271,7 +291,7 @@ WundergroundIon::updateIonSource( const QString & sSource )
 		dEndFunct();
 		return true;
 	}
-	else if( vTokens.at(1) == ActionWeather )
+	else if( vTokens.size() >= 3 && vTokens.at(1) == ActionWeather )
 	{
 		bool bValid(false);
 		if( vTokens.size() >= 4 )
@@ -287,6 +307,15 @@ WundergroundIon::updateIonSource( const QString & sSource )
 		dEndFunct();
 		return true;
 	}
+	else
+	{
+#if KDE_IS_VERSION(4,4,80)
+		setData(sSource, "validate", QString("%1|malformed").arg(IonName)); 
+#else
+		setData(sSource, "validate", QString("%1|timeout").arg(IonName));
+#endif
+
+	}
 	dEndFunct();
 	return false;
 }
@@ -524,11 +553,13 @@ WundergroundIon::slotJobFinished( KJob * job )
 				readCurrentObservation(pXmlData->xmlReader, *pWeatherData);
 			else if( job->objectName().compare(XmlDataForecast) == 0 )
 				readWeatherForecast(pXmlData->xmlReader, *pWeatherData);
+			
+			pWeatherData->iSuccededJobs += 1;
 		}	
 		pWeatherData->iActiveJobs -= 1;
 		dDebug() << "active jobs for " << pXmlData->sServiceId << pWeatherData->iActiveJobs;
 			
-		if( pWeatherData->iActiveJobs <= 0 )
+		if( pWeatherData->iActiveJobs <= 0 && pWeatherData->iSuccededJobs > 0 )
 		{
 			updateWeatherSource( *pWeatherData, pXmlData->sSource, pXmlData->sLocation );
 			
@@ -617,6 +648,7 @@ WundergroundIon::getWeatherData( const QString & sLocation, const QString & sSer
 	{
 		XmlWeatherData * pXmlWeatherData = new XmlWeatherData;
 		pXmlWeatherData->iActiveJobs = iJobCounter;
+		pXmlWeatherData->iSuccededJobs = 0;
 		pXmlWeatherData->measureSystem = KGlobal::locale()->measureSystem();
 		
 		d->vWeatherData.insert(sServiceId, pXmlWeatherData);
@@ -742,24 +774,16 @@ WundergroundIon::readWeatherForecast( QXmlStreamReader & xml, XmlWeatherData & d
 				XmlForecastDay * pForecast = d->parseForecastDay(xml, data.measureSystem, data.sTimeZone);
 				if( pForecast )
 				{
-//					dDebug() << "ForecastIcon:" << pForecast->sIcon;
 					pForecast->sIcon = getWeatherIcon(d->vIconConditionMap, pForecast->sIcon);
-//					dDebug() << "   " << pForecast->sIcon;
 					data.vForecasts.append(pForecast);
 				}
 			}
 			else if( bMoonPhase )
 			{
 				if( xml.name().compare("sunrise") == 0 )
-				{
 					data.sunrise = d->parseTime(xml);
-//					dDebug() << "Sunrise:" << data.sunrise;
-				}
 				else if( xml.name().compare("sunset") == 0 )
-				{
 					data.sunset = d->parseTime(xml);
-//					dDebug() <<"Sunset:" << data.sunset;
-				}
 			}
 			iLevel += 1;
 		}
@@ -849,7 +873,9 @@ WundergroundIon::updateWeatherSource( const XmlWeatherData & data, const QString
 	setData(sSource, "Visibility Unit", QString::number(iDistanceSystem) );
 	setData(sSource, "Wind Speed Unit",  QString::number(iSpeedSystem) );
 
-	setData(sSource, "Condition Icon", data.sCurrentIcon);
+	setData(sSource, "Condition Icon", getWeatherIcon(d->vIconConditionMap, d->stringConverter(data.sCurrentIcon) ) );
+	setData(sSource, "Current Conditions", d->stringConverter(data.sDayCondition) );
+
 	setData(sSource, "Dewpoint", d->stringConverter(data.sDewpoint) );
 	setData(sSource, "Humidity", d->stringConverter(data.sHumidity) );
 	setData(sSource, "Pressure", d->stringConverter(data.sPressure) );
@@ -1030,12 +1056,7 @@ WundergroundIon::Private::parseForecastDay( QXmlStreamReader & xml,
 			if( xml.name().compare("period") == 0 )
 				iPeriod = xml.readElementText().toInt();
 			else if( xml.name().compare("weekday") == 0 )
-			{
-				if( iPeriod == 1 )
-					pDay->sDayName = "Today";
-				else
-					pDay->sDayName = i18n(xml.readElementText().left(3).toUtf8().constData());
-			}
+				pDay->sDayName = i18n(xml.readElementText().left(3).toUtf8().constData());
 			else if( xml.name().compare("tz_long") == 0 )
 				sTimeZone = xml.readElementText();
 			else if( xml.name().compare("conditions") == 0 )
@@ -1093,6 +1114,8 @@ WundergroundIon::Private::parseTextCondition( QXmlStreamReader & xml, XmlWeather
 	short   iLevel(1);
 	short   iPeriode(-1);
 	QString sText;
+	QString sIcon;
+	QDate   date;
 	
 	while( !xml.atEnd() )
 	{
@@ -1103,21 +1126,28 @@ WundergroundIon::Private::parseTextCondition( QXmlStreamReader & xml, XmlWeather
 				iPeriode = xml.readElementText().toShort();
 			else if( xml.name().compare("fcttext") == 0 )
 				sText = xml.readElementText();
+			else if(xml.name().compare("icon") == 0 )
+				sIcon = xml.readElementText();
+			else if( xml.name().compare("title") == 0 )
+				date = QDate::fromString(xml.readElementText(), "MMMM d, yyyy");
 			iLevel += 1;
 		}
 		if( xml.isEndElement() )
 		{
 			iLevel -= 1;
 			if( xml.name().compare("forecastday") == 0 )
-			{
-				if( !sText.isEmpty() && iPeriode == 1 )
-					data.sDayCondition = sText;
-				else if( !sText.isEmpty() && iPeriode == 2 )
-					data.sNightCondition = sText;
 				break;
-			}
 		}
 	}
+	
+	dDebug() << "Forecast Condition Period: " << iPeriode << sIcon << sText;
+	if( !sText.isEmpty() &&
+	    date.isValid() &&
+	    iPeriode == 0 )
+	{
+		data.sDayCondition = sText;
+		data.sCurrentIcon = sIcon;
+	}
 }
 
 QTime
